/****************************************************************************
 * FILE NAME: etpu_crank_common.h,        Copyright (C) 2010 ASH WARE, Inc. *
 * DESCRIPTION:                                     All Rights Reserved     *
 * This header contains all definitions common between eTPU code and the    *
 * host-side API software.  For example, it contains HSR and Function Mode  *
 * definitions.  In the past this information has been shared with the host *
 * through export and an extra layer of indirection.  ASH WARE is promoting *
 * this technique wherein these definitions exist in only one place and are *
 * included into eTPU code, host-side code and simulator scripts as needed. *
 *==========================================================================*
 * ORIGINAL AUTHOR: John Diener                                             *
 ****************************************************************************/

#ifndef __ETPU_CRANK_COMMON_H
#define __ETPU_CRANK_COMMON_H

/* Host Service Requests */
#define CRANK_INIT            7
#define CRANK_IPH             3
#define CRANK_ANGLE_ADJUST    1

/* Function Modes */
#define CRANK_FM0_ACTIVE_RISING_EDGE 1
#define CRANK_FM0_ACTIVE_FALLING_EDGE 0

/* ENG_POS Sync States */
#define ENG_POS_SEEK                0
#define ENG_POS_FIRST_HALF_SYNC     1
#define ENG_POS_PRE_FULL_SYNC       2
#define ENG_POS_FULL_SYNC           3
#define ENG_POS_HALF_SYNC           4

/* CRANK Error codes */
#define CRANK_NO_ERROR               0
#define CRANK_INVALID_M1             1
#define CRANK_INVALID_M2             2
#define CRANK_TIMEOUT                4
#define CRANK_STALL                  8
#define CRANK_INTERNAL_ERROR         16

#endif // __ETPU_CRANK_COMMON_H

/*********************************************************************
 *
 * Copyright:
 *  ASH WARE Inc. All Rights Reserved.
 *  You are hereby granted a copyright license to use, modify, and
 *  distribute the SOFTWARE so long as this entire notice is
 *  retained without alteration in any modified and/or redistributed
 *  versions, and that such modified versions are clearly identified
 *  as such. No licenses are granted by implication, estoppel or
 *  otherwise under any patents or trademarks of ASH WARE Inc.
 *  This software is provided on an "AS IS" basis and without warranty.
 *
 *  To the maximum extent permitted by applicable law, ASH WARE
 *  DISCLAIMS ALL WARRANTIES WHETHER EXPRESS OR IMPLIED,
 *  INCLUDING IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A
 *  PARTICULAR PURPOSE AND ANY WARRANTY AGAINST INFRINGEMENT WITH
 *  REGARD TO THE SOFTWARE (INCLUDING ANY MODIFIED VERSIONS THEREOF)
 *  AND ANY ACCOMPANYING WRITTEN MATERIALS.
 *
 *  To the maximum extent permitted by applicable law, IN NO EVENT
 *  SHALL ASH WARE BE LIABLE FOR ANY DAMAGES WHATSOEVER
 *  (INCLUDING WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS,
 *  BUSINESS INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR OTHER
 *  PECUNIARY LOSS) ARISING OF THE USE OR INABILITY TO USE THE SOFTWARE.
 *
 *  ASH WARE assumes no responsibility for the
 *  maintenance and support of this software
 ********************************************************************/
